@@ -88,6 +88,11 @@
         <source>About</source>
         <translation>Tietoja</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>Broken Symlink!</source>
+        <translation>Puuttuva symbolinen linkki!</translation>
+    </message>
 </context>
 <context>
     <name>BookWindow</name>
@@ -102,7 +107,7 @@
     <message>
         <location filename="../home.cpp" line="10"/>
         <source>Home folder</source>
-        <translation>Kotihakemistol</translation>
+        <translation>Kotihakemisto</translation>
     </message>
     <message>
         <location filename="../home.cpp" line="10"/>
@@ -158,6 +163,11 @@
         <source>Create new document</source>
         <translation>Luo uusi dokumentti</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Open terminal here</source>
+        <translation>Avaa konsoli tässä</translation>
+    </message>
     <message>
         <location filename="../toolsdialog.cpp" line="10"/>
         <source>Sort</source>
@@ -227,7 +237,7 @@
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
         <source>Cannot create destination directory.</source>
-        <translation>&gt;Kohdehakemistoa ei voi luoda.</translation>
+        <translation>Kohdehakemistoa ei voi luoda.</translation>
     </message>
     <message>
         <location filename="../qtcopydialog.cpp" line="10"/>
@@ -443,6 +453,31 @@
         <source>Enable multiselection</source>
         <translation>Salli monen tiedoston valitseminen</translation>
     </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Auto select items in clipboard</source>
+        <translation>Valitse leikepöydältä automaattisesti</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Orientation</source>
+        <translation>Suunta</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Automatic</source>
+        <translation>Automaattinen</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Portrait</source>
+        <translation>Pysty</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="10"/>
+        <source>Landscape</source>
+        <translation>Vaaka</translation>
+    </message>
 </context>
 <context>
     <name>NewFolder</name>
@@ -563,6 +598,16 @@
         <source>Sort</source>
         <translation>Järjestä</translation>
     </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Ascending</source>
+        <translation>Nouseva</translation>
+    </message>
+    <message>
+        <location filename="../sort.cpp" line="10"/>
+        <source>Descending</source>
+        <translation>Laskeva</translation>
+    </message>
     <message>
         <location filename="../sort.cpp" line="10"/>
         <source>Name (A-Z)</source>
